Module: Nestor::Mappers
- Defined in:
- lib/nestor/mappers.rb,
lib/nestor/mappers/rails/test/unit.rb
Overview
Cli will require a file named nestor/mappers/#{framework}/#{test_framework}. If you want
to provide custom mappers, it is possible to do so.
Mappers are simple objects that implement the following protocol:
- default_script_path
Class method to return the path to the default Watchr script. This must be a physical file on the filesystem, as Watchr cannot accept anything else at the moment.
- log(message)
Logs a simple message, either to the console or a logfile. The Machine will use the
logmethod to notify about it's state transitions.- run_all
Runs all the tests, no matter what. In the Rails::Test::Unit case, this means Dir.
- run(tests_files, focused_cases=[])
Runs only a subset of the tests, maybe focusing on only a couple of tests / examples.
- map(file)
Given an implementation file, returns the corresponding test to run. Rails::Test::Unit maps
app/models/user.rbtotest/unit/user_test.rb.
Defined Under Namespace
Modules: Rails